==> ansible-11.0.0a1.tar.gz: ansible-11.0.0a1/ansible_collections/cisco/dnac/plugins/action/pnp_device_info.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import (absolute_import, division, print_function)
__metaclass__ = type
from ansible.plugins.action import ActionBase
try:
    from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
        AnsibleArgSpecValidator,
    )
except ImportError:
    ANSIBLE_UTILS_IS_INSTALLED = False
else:
    ANSIBLE_UTILS_IS_INSTALLED = True
from ansible.errors import AnsibleActionFail
from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
    DNACSDK,
    dnac_argument_spec,
)

# Get common arguments specification
argument_spec = dnac_argument_spec()
# Add arguments specific for this module
argument_spec.update(dict(
    limit=dict(type="int"),
    offset=dict(type="int"),
    sort=dict(type="list"),
    sortOrder=dict(type="str"),
    serialNumber=dict(type="list"),
    state_=dict(type="list"),
    onbState=dict(type="list"),
    name=dict(type="list"),
    pid=dict(type="list"),
    source=dict(type="list"),
    workflowId=dict(type="list"),
    workflowName=dict(type="list"),
    smartAccountId=dict(type="list"),
    virtualAccountId=dict(type="list"),
    lastContact=dict(type="bool"),
    macAddress=dict(type="str"),
    hostname=dict(type="str"),
    siteName=dict(type="str"),
    id=dict(type="str"),
    headers=dict(type="dict"),
))

required_if = []
required_one_of = []
mutually_exclusive = []
required_together = []


class ActionModule(ActionBase):
    def __init__(self, *args, **kwargs):
        if not ANSIBLE_UTILS_IS_INSTALLED:
            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
        super(ActionModule, self).__init__(*args, **kwargs)
        self._supports_async = False
        self._supports_check_mode = True
        self._result = None

    # Checks the supplied parameters against the argument spec for this module
    def _check_argspec(self):
        aav = AnsibleArgSpecValidator(
            data=self._task.args,
            schema=dict(argument_spec=argument_spec),
            schema_format="argspec",
            schema_conditionals=dict(
                required_if=required_if,
                required_one_of=required_one_of,
                mutually_exclusive=mutually_exclusive,
                required_together=required_together,
            ),
            name=self._task.action,
        )
        valid, errors, self._task.args = aav.validate()
        if not valid:
            raise AnsibleActionFail(errors)

    def get_object(self, params):
        new_object = dict(
            limit=params.get("limit"),
            offset=params.get("offset"),
            sort=params.get("sort"),
            sort_order=params.get("sortOrder"),
            serial_number=params.get("serialNumber"),
            state=params.get("state_"),
            onb_state=params.get("onbState"),
            name=params.get("name"),
            pid=params.get("pid"),
            source=params.get("source"),
            workflow_id=params.get("workflowId"),
            workflow_name=params.get("workflowName"),
            smart_account_id=params.get("smartAccountId"),
            virtual_account_id=params.get("virtualAccountId"),
            last_contact=params.get("lastContact"),
            mac_address=params.get("macAddress"),
            hostname=params.get("hostname"),
            site_name=params.get("siteName"),
            id=params.get("id"),
            headers=params.get("headers"),
        )
        return new_object

    def run(self, tmp=None, task_vars=None):
        self._task.diff = False
        self._result = super(ActionModule, self).run(tmp, task_vars)
        self._result["changed"] = False
        self._check_argspec()

        self._result.update(dict(dnac_response={}))

        dnac = DNACSDK(params=self._task.args)

        id = self._task.args.get("id")
        if id:
            response = dnac.exec(
                family="device_onboarding_pnp",
                function='get_device_by_id',
                params=self.get_object(self._task.args),
            )
            self._result.update(dict(dnac_response=response))
            self._result.update(dnac.exit_json())
            return self._result
        if not id:
            response = dnac.exec(
                family="device_onboarding_pnp",
                function='get_device_list',
                params=self.get_object(self._task.args),
            )
            self._result.update(dict(dnac_response=response))
            self._result.update(dnac.exit_json())
            return self._result

==> ansible-12.0.0a9.tar.gz: ansible-12.0.0a9/ansible_collections/cisco/dnac/plugins/action/pnp_device_info.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or
# https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type
from ansible.plugins.action import ActionBase

try:
    from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
        AnsibleArgSpecValidator,
    )
except ImportError:
    ANSIBLE_UTILS_IS_INSTALLED = False
else:
    ANSIBLE_UTILS_IS_INSTALLED = True
from ansible.errors import AnsibleActionFail
from ansible_collections.cisco.dnac.plugins.plugin_utils.dnac import (
    DNACSDK,
    dnac_argument_spec,
)

# Get common arguments specification
argument_spec = dnac_argument_spec()
# Add arguments specific for this module
argument_spec.update(
    dict(
        limit=dict(type="float"),
        offset=dict(type="float"),
        sort=dict(type="list"),
        sortOrder=dict(type="str"),
        serialNumber=dict(type="list"),
        state_=dict(type="list"),
        onbState=dict(type="list"),
        name=dict(type="list"),
        pid=dict(type="list"),
        source=dict(type="list"),
        workflowId=dict(type="list"),
        workflowName=dict(type="list"),
        smartAccountId=dict(type="list"),
        virtualAccountId=dict(type="list"),
        lastContact=dict(type="bool"),
        macAddress=dict(type="str"),
        hostname=dict(type="str"),
        siteName=dict(type="str"),
        id=dict(type="str"),
        headers=dict(type="dict"),
    )
)

required_if = []
required_one_of = []
mutually_exclusive = []
required_together = []


class ActionModule(ActionBase):
    def __init__(self, *args, **kwargs):
        if not ANSIBLE_UTILS_IS_INSTALLED:
            raise AnsibleActionFail(
                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
            )
        super(ActionModule, self).__init__(*args, **kwargs)
        self._supports_async = False
        self._supports_check_mode = True
        self._result = None

    # Checks the supplied parameters against the argument spec for this module
    def _check_argspec(self):
        aav = AnsibleArgSpecValidator(
            data=self._task.args,
            schema=dict(argument_spec=argument_spec),
            schema_format="argspec",
            schema_conditionals=dict(
                required_if=required_if,
                required_one_of=required_one_of,
                mutually_exclusive=mutually_exclusive,
                required_together=required_together,
            ),
            name=self._task.action,
        )
        valid, errors, self._task.args = aav.validate()
        if not valid:
            raise AnsibleActionFail(errors)

    def get_object(self, params):
        new_object = dict(
            limit=params.get("limit"),
            offset=params.get("offset"),
            sort=params.get("sort"),
            sort_order=params.get("sortOrder"),
            serial_number=params.get("serialNumber"),
            state=params.get("state_"),
            onb_state=params.get("onbState"),
            name=params.get("name"),
            pid=params.get("pid"),
            source=params.get("source"),
            workflow_id=params.get("workflowId"),
            workflow_name=params.get("workflowName"),
            smart_account_id=params.get("smartAccountId"),
            virtual_account_id=params.get("virtualAccountId"),
            last_contact=params.get("lastContact"),
            mac_address=params.get("macAddress"),
            hostname=params.get("hostname"),
            site_name=params.get("siteName"),
            id=params.get("id"),
            headers=params.get("headers"),
        )
        return new_object

    def run(self, tmp=None, task_vars=None):
        self._task.diff = False
        self._result = super(ActionModule, self).run(tmp, task_vars)
        self._result["changed"] = False
        self._check_argspec()

        self._result.update(dict(dnac_response={}))

        dnac = DNACSDK(params=self._task.args)

        id = self._task.args.get("id")
        if id:
            response = dnac.exec(
                family="device_onboarding_pnp",
                function="get_device_by_id",
                params=self.get_object(self._task.args),
            )
            self._result.update(dict(dnac_response=response))
            self._result.update(dnac.exit_json())
            return self._result
        if not id:
            response = dnac.exec(
                family="device_onboarding_pnp",
                function="get_device_list",
                params=self.get_object(self._task.args),
            )
            self._result.update(dict(dnac_response=response))
            self._result.update(dnac.exit_json())
            return self._result
